All Classes and Interfaces

Class
Description
 
 
 
 
 
 
 
tag a method with this who's only parameter is a class that extends Event
 
 
A handler for managing protocol specific bounce packets.
 
Used to facilitate protocols over bounce packets.
 
 
 
A Status to send to the server.
 
 
 
 
 
 
 
 
 
event that is fired whenever you receive a death link from another player.
 
 
Manages registering and calling events
 
 
Used to request a single or multiple values from the server's data storage, see the ArchipelagoClient.dataStorageSet() for how to write values to the data storage.
 
 
 
 
 
 
 
 
 
 
Flags that will tell you more about the item that was sent.
NetworkItem.ADVANCEMENT, NetworkItem.USEFUL, NetworkItem.TRAP
 
Flags that will tell you more about the slot type.
NetworkPlayer.SPECTATOR, NetworkPlayer.PLAYER, NetworkPlayer.GROUP
 
 
 
event that is fired when the server wishes to send a message to the user.