Index
All Classes and Interfaces|All Packages|Constant Field Values|Serialized Form
A
- ADD - Enum constant in enum class io.github.archipelagomw.network.client.SetPacket.Operation
-
Adds value to the current value of the key on the server, if both the current value and value are arrays then value will be appended to the current @value.
- addCheckedLocations(Set<Long>) - Method in class io.github.archipelagomw.LocationManager
- addDataStorageOperation(SetPacket.Operation, Object) - Method in class io.github.archipelagomw.network.client.SetPacket
-
adds a
SetPacket.DataStorageOperationto be performed to the value on the server, these are applied in the order that you add them. - addHandler(BouncedPacketHandler) - Method in class io.github.archipelagomw.bounce.BouncedManager
-
Adds a handler to intercept bounce packets with
- addTag(String) - Method in class io.github.archipelagomw.Client
-
add a tag to your list, keeping all previous tags intact.
- AdminCommandResult - Enum constant in enum class io.github.archipelagomw.Print.APPrintJsonType
-
The client entered an !admin command.
- ADVANCEMENT - Static variable in class io.github.archipelagomw.flags.NetworkItem
-
If set, indicates the item can unlock logical advancement
- alias - Variable in class io.github.archipelagomw.parts.NetworkPlayer
- AND - Enum constant in enum class io.github.archipelagomw.network.client.SetPacket.Operation
-
Applies a bitwise AND to the current value on the server of the key with @value.
- APPacket - Class in io.github.archipelagomw.network
- APPacket(APPacketType) - Constructor for class io.github.archipelagomw.network.APPacket
- APPacketType - Enum Class in io.github.archipelagomw.network
- apPrint - Variable in class io.github.archipelagomw.events.PrintJSONEvent
- APPrint - Class in io.github.archipelagomw.Print
- APPrint() - Constructor for class io.github.archipelagomw.Print.APPrint
- APPrintColor - Enum Class in io.github.archipelagomw.Print
- APPrintJsonType - Enum Class in io.github.archipelagomw.Print
- APPrintPart - Class in io.github.archipelagomw.Print
- APPrintPart() - Constructor for class io.github.archipelagomw.Print.APPrintPart
- APPrintType - Enum Class in io.github.archipelagomw.Print
- APResult<T> - Class in io.github.archipelagomw
-
Small container class for the outcome of client requests.
- APResult.ResultCode - Enum Class in io.github.archipelagomw
- ArchipelagoEventListener - Annotation Interface in io.github.archipelagomw.events
-
tag a method with this who's only parameter is a class that extends
Event - AtomicDouble - Class in io.github.archipelagomw.utils
- AtomicDouble(double) - Constructor for class io.github.archipelagomw.utils.AtomicDouble
- auto - Enum constant in enum class io.github.archipelagomw.network.Permission
- auto - Enum constant in enum class io.github.archipelagomw.network.RemainingMode.ForfeitMode
- auto_enabled - Enum constant in enum class io.github.archipelagomw.network.Permission
- autoEnabled - Enum constant in enum class io.github.archipelagomw.network.RemainingMode.ForfeitMode
B
- black - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
- black_bg - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
- blue - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
- blue_bg - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
- bold - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
- Bounce - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- Bounced - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- BouncedEvent - Class in io.github.archipelagomw.events
- BouncedEvent(HashSet<String>, HashSet<String>, HashSet<Integer>, HashMap<String, Object>) - Constructor for class io.github.archipelagomw.events.BouncedEvent
- BouncedManager - Class in io.github.archipelagomw.bounce
-
A handler for managing protocol specific bounce packets.
- BouncedManager() - Constructor for class io.github.archipelagomw.bounce.BouncedManager
- BouncedPacket - Class in io.github.archipelagomw.network.server
- BouncedPacket() - Constructor for class io.github.archipelagomw.network.server.BouncedPacket
- BouncedPacketHandler - Interface in io.github.archipelagomw.bounce
-
Used to facilitate protocols over bounce packets.
- BouncePacket - Class in io.github.archipelagomw.network.client
- BouncePacket() - Constructor for class io.github.archipelagomw.network.client.BouncePacket
- BROADCAST_ALWAYS - Enum constant in enum class io.github.archipelagomw.network.client.CreateAsHint
- BROADCAST_NEW - Enum constant in enum class io.github.archipelagomw.network.client.CreateAsHint
C
- callEvent(Event) - Method in class io.github.archipelagomw.EventManager
- canHandle(BouncedPacket) - Method in interface io.github.archipelagomw.bounce.BouncedPacketHandler
-
Whether this BouncedPacketHandler can handle the provided packet.
- canHandle(BouncedPacket) - Method in class io.github.archipelagomw.bounce.DeathLinkHandler
- cause - Variable in class io.github.archipelagomw.events.DeathLinkEvent
- Chat - Enum constant in enum class io.github.archipelagomw.Print.APPrintJsonType
-
A player sent a chat message.
- checkedLocations - Variable in class io.github.archipelagomw.events.CheckedLocationsEvent
- checkedLocations - Variable in class io.github.archipelagomw.network.server.ConnectedPacket
- checkedLocations - Variable in class io.github.archipelagomw.network.server.RoomUpdatePacket
- CheckedLocationsEvent - Class in io.github.archipelagomw.events
- CheckedLocationsEvent(ArrayList<Long>) - Constructor for class io.github.archipelagomw.events.CheckedLocationsEvent
- checkLocation(long) - Method in class io.github.archipelagomw.Client
-
inform the Archipelago server that a location ID has been checked.
- checkLocation(long) - Method in class io.github.archipelagomw.LocationManager
- checkLocations(Collection<Long>) - Method in class io.github.archipelagomw.Client
-
inform the Archipelago server that a collection of location ID has been checked.
- checkLocations(Collection<Long>) - Method in class io.github.archipelagomw.LocationManager
- checksum - Variable in class io.github.archipelagomw.parts.Game
- client - Static variable in class io.github.archipelagomw.Client
- Client - Class in io.github.archipelagomw
- Client() - Constructor for class io.github.archipelagomw.Client
- CLIENT_GOAL - Enum constant in enum class io.github.archipelagomw.ClientStatus
- CLIENT_PLAYING - Enum constant in enum class io.github.archipelagomw.ClientStatus
- CLIENT_READY - Enum constant in enum class io.github.archipelagomw.ClientStatus
- CLIENT_UNKNOWN - Enum constant in enum class io.github.archipelagomw.ClientStatus
- ClientStatus - Enum Class in io.github.archipelagomw
-
A Status to send to the server.
- close() - Method in class io.github.archipelagomw.Client
-
closes a connection to the Archipelago server if connected.
- Collect - Enum constant in enum class io.github.archipelagomw.Print.APPrintJsonType
-
A player collected the remaining items for their world.
- color - Enum constant in enum class io.github.archipelagomw.Print.APPrintType
- color - Variable in enum class io.github.archipelagomw.Print.APPrintColor
- color - Variable in class io.github.archipelagomw.Print.APPrintPart
- CommandResult - Enum constant in enum class io.github.archipelagomw.Print.APPrintJsonType
-
Someone (usually the client) entered an ! command.
- connect(String) - Method in class io.github.archipelagomw.Client
-
Works exactly like
Client.connect(URI, boolean)with allowDowngrade set to true; - connect(URI) - Method in class io.github.archipelagomw.Client
-
Works exactly like
Client.connect(URI, boolean)but allowDowngrade is False - connect(URI, boolean) - Method in class io.github.archipelagomw.Client
-
Equivalent to
Client.connect(URI, boolean, SocketFactory)socketFactory being null. - connect(URI, boolean, SocketFactory) - Method in class io.github.archipelagomw.Client
-
Connects to an Archipelago server with previously provided info.
- Connect - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- Connected - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- ConnectedPacket - Class in io.github.archipelagomw.network.server
- ConnectedPacket() - Constructor for class io.github.archipelagomw.network.server.ConnectedPacket
- ConnectionAttemptEvent - Class in io.github.archipelagomw.events
- ConnectionAttemptEvent(int, int, String, JsonElement) - Constructor for class io.github.archipelagomw.events.ConnectionAttemptEvent
- ConnectionRefused - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- ConnectionRefusedPacket - Class in io.github.archipelagomw.network.server
- ConnectionRefusedPacket() - Constructor for class io.github.archipelagomw.network.server.ConnectionRefusedPacket
- ConnectionResult - Enum Class in io.github.archipelagomw.network
- ConnectionResultEvent - Class in io.github.archipelagomw.events
- ConnectionResultEvent(ConnectionResult) - Constructor for class io.github.archipelagomw.events.ConnectionResultEvent
- ConnectionResultEvent(ConnectionResult, int, int, String, JsonElement) - Constructor for class io.github.archipelagomw.events.ConnectionResultEvent
- ConnectPacket - Class in io.github.archipelagomw.network.client
- ConnectPacket() - Constructor for class io.github.archipelagomw.network.client.ConnectPacket
- ConnectUpdate - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- ConnectUpdatePacket - Class in io.github.archipelagomw.network.server
- ConnectUpdatePacket() - Constructor for class io.github.archipelagomw.network.server.ConnectUpdatePacket
- containsKey(String) - Method in class io.github.archipelagomw.events.BouncedEvent
- containsKey(String) - Method in class io.github.archipelagomw.events.RetrievedEvent
- countdown - Variable in class io.github.archipelagomw.Print.APPrint
- Countdown - Enum constant in enum class io.github.archipelagomw.Print.APPrintJsonType
-
The current server countdown has progressed.
- create(Gson, TypeToken<T>) - Method in class io.github.archipelagomw.utils.IntEnumAdapterFactory
- createAsHint - Variable in class io.github.archipelagomw.network.client.LocationScouts
- CreateAsHint - Enum Class in io.github.archipelagomw.network.client
- CreateHintPacket - Class in io.github.archipelagomw.network.client
- CreateHintPacket(List<Long>, int) - Constructor for class io.github.archipelagomw.network.client.CreateHintPacket
- CreateHintPacket(List<Long>, int, HintStatus) - Constructor for class io.github.archipelagomw.network.client.CreateHintPacket
- createHints(List<Long>) - Method in class io.github.archipelagomw.Client
-
Creates hints for the provided locations with this client's slot
- createHints(List<Long>, int) - Method in class io.github.archipelagomw.Client
-
Creates hints for the provided locations
- createHints(List<Long>, int, HintStatus) - Method in class io.github.archipelagomw.Client
-
Creates hints for the provided locations
- CreateHints - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- cyan - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
- cyan_bg - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
D
- data - Variable in class io.github.archipelagomw.events.RetrievedEvent
- data - Variable in class io.github.archipelagomw.network.server.BouncedPacket
- DataPackage - Class in io.github.archipelagomw.parts
- DataPackage - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- DataPackage() - Constructor for class io.github.archipelagomw.parts.DataPackage
- datapackageChecksums - Variable in class io.github.archipelagomw.network.server.RoomInfoPacket
- datapackageChecksums - Variable in class io.github.archipelagomw.network.server.RoomUpdatePacket
- datapackageVersion - Variable in class io.github.archipelagomw.network.server.RoomUpdatePacket
- dataStorageGet(Collection<String>) - Method in class io.github.archipelagomw.Client
-
Uses DataStorage to reterieve a value from the server will get value back though a
RetrievedEvent. - dataStorageSet(SetPacket) - Method in class io.github.archipelagomw.Client
-
Uses DataStorage to save a value on the AP server.
- dataStorageSetNotify(Collection<String>) - Method in class io.github.archipelagomw.Client
-
Registers to receive updates of when a key in the Datastorage has been changed on the server.
- DEATHLINK_TAG - Static variable in class io.github.archipelagomw.bounce.DeathLinkHandler
- DeathLinkEvent - Class in io.github.archipelagomw.events
-
event that is fired whenever you receive a death link from another player.
- DeathLinkEvent(String, String, double) - Constructor for class io.github.archipelagomw.events.DeathLinkEvent
- DeathLinkHandler - Class in io.github.archipelagomw.bounce
- DeathLinkHandler(Client) - Constructor for class io.github.archipelagomw.bounce.DeathLinkHandler
- DEFAULT - Enum constant in enum class io.github.archipelagomw.network.client.SetPacket.Operation
-
If the key has no value yet, Sets the current value of the key on the server to the default of the Set's package (@value is ignored).
- defaultValue - Variable in class io.github.archipelagomw.network.client.SetPacket
-
The default value to use in case the key has no value on the server.
- disabled - Enum constant in enum class io.github.archipelagomw.network.Permission
- disabled - Enum constant in enum class io.github.archipelagomw.network.RemainingMode
- disabled - Enum constant in enum class io.github.archipelagomw.network.RemainingMode.ForfeitMode
- disconnect() - Method in class io.github.archipelagomw.Client
-
disconnects from a connected Archipelago server.
- disconnected() - Static method in class io.github.archipelagomw.APResult
- DISCONNECTED - Enum constant in enum class io.github.archipelagomw.APResult.ResultCode
E
- enabled - Enum constant in enum class io.github.archipelagomw.network.Permission
- enabled - Enum constant in enum class io.github.archipelagomw.network.RemainingMode
- enabled - Enum constant in enum class io.github.archipelagomw.network.RemainingMode.ForfeitMode
- ensureConnectedAndAuth() - Method in class io.github.archipelagomw.Client
- entranceName - Enum constant in enum class io.github.archipelagomw.Print.APPrintType
- error() - Static method in class io.github.archipelagomw.APResult
- errors - Variable in class io.github.archipelagomw.network.server.ConnectionRefusedPacket
- Event - Interface in io.github.archipelagomw.events
- EventManager - Class in io.github.archipelagomw
-
Manages registering and calling events
- EventManager() - Constructor for class io.github.archipelagomw.EventManager
F
- flags - Variable in class io.github.archipelagomw.parts.NetworkItem
-
Bit flags that tell you information about the item.
- flags - Variable in class io.github.archipelagomw.Print.APPrintPart
- forfeitMode - Variable in class io.github.archipelagomw.network.server.RoomUpdatePacket
- found - Variable in class io.github.archipelagomw.Print.APPrint
G
- game - Variable in class io.github.archipelagomw.network.client.ConnectPacket
- game - Variable in class io.github.archipelagomw.parts.NetworkSlot
- Game - Class in io.github.archipelagomw.parts
- Game() - Constructor for class io.github.archipelagomw.parts.Game
- games - Variable in class io.github.archipelagomw.Client
- games - Variable in class io.github.archipelagomw.events.BouncedEvent
- games - Variable in class io.github.archipelagomw.network.client.BouncePacket
- games - Variable in class io.github.archipelagomw.network.server.BouncedPacket
- games - Variable in class io.github.archipelagomw.network.server.RoomInfoPacket
- generatorVersion - Variable in class io.github.archipelagomw.network.server.RoomInfoPacket
- get() - Method in class io.github.archipelagomw.utils.AtomicDouble
- Get - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- getAlias() - Method in class io.github.archipelagomw.Client
-
gets the alias of this slot.
- getAndUpdate(DoubleUnaryOperator) - Method in class io.github.archipelagomw.utils.AtomicDouble
- getBoolean(String) - Method in class io.github.archipelagomw.events.BouncedEvent
- getBoolean(String) - Method in class io.github.archipelagomw.events.RetrievedEvent
- getBouncedManager() - Method in class io.github.archipelagomw.Client
- getCheckedLocations() - Method in class io.github.archipelagomw.LocationManager
- getChecksums() - Method in class io.github.archipelagomw.parts.DataPackage
- getCmd() - Method in class io.github.archipelagomw.network.APPacket
- getCode() - Method in class io.github.archipelagomw.APResult
- getConnectedAddress() - Method in class io.github.archipelagomw.Client
- getData() - Method in class io.github.archipelagomw.network.client.BouncePacket
- getDataPackage() - Method in class io.github.archipelagomw.Client
- GetDataPackage - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- GetDataPackagePacket - Class in io.github.archipelagomw.network.client
- GetDataPackagePacket() - Constructor for class io.github.archipelagomw.network.client.GetDataPackagePacket
- GetDataPackagePacket(Set<String>) - Constructor for class io.github.archipelagomw.network.client.GetDataPackagePacket
- getDouble(String) - Method in class io.github.archipelagomw.events.BouncedEvent
- getDouble(String) - Method in class io.github.archipelagomw.events.RetrievedEvent
- getEventManager() - Method in class io.github.archipelagomw.Client
- getFileSafeName(String) - Static method in class io.github.archipelagomw.Utils
- getFloat(String) - Method in class io.github.archipelagomw.events.BouncedEvent
- getFloat(String) - Method in class io.github.archipelagomw.events.RetrievedEvent
- getGame() - Method in class io.github.archipelagomw.Client
- getGame(String) - Method in class io.github.archipelagomw.parts.DataPackage
- getGames() - Method in class io.github.archipelagomw.parts.DataPackage
- getHintPoints() - Method in class io.github.archipelagomw.Client
- getIndex() - Method in class io.github.archipelagomw.events.ReceiveItemEvent
- getIndex() - Method in class io.github.archipelagomw.ItemManager
- getInt(String) - Method in class io.github.archipelagomw.events.BouncedEvent
- getInt(String) - Method in class io.github.archipelagomw.events.RetrievedEvent
- getItem() - Method in class io.github.archipelagomw.events.ReceiveItemEvent
- getItem(long) - Method in class io.github.archipelagomw.parts.Game
- getItem(long, String) - Method in class io.github.archipelagomw.parts.DataPackage
- getItemID() - Method in class io.github.archipelagomw.events.ReceiveItemEvent
- getItemManager() - Method in class io.github.archipelagomw.Client
- getItemName() - Method in class io.github.archipelagomw.events.ReceiveItemEvent
- getItemsHandlingFlags() - Method in class io.github.archipelagomw.Client
-
fetch the itemflags that have been set, bitwise Or against
ItemsHandlingto read. - getLocation(long) - Method in class io.github.archipelagomw.parts.Game
- getLocation(long, String) - Method in class io.github.archipelagomw.parts.DataPackage
- getLocationID() - Method in class io.github.archipelagomw.events.ReceiveItemEvent
- getLocationManager() - Method in class io.github.archipelagomw.Client
- getLocationName() - Method in class io.github.archipelagomw.events.ReceiveItemEvent
- getMissingLocations() - Method in class io.github.archipelagomw.LocationManager
- getMyName() - Method in class io.github.archipelagomw.Client
- getObject(String) - Method in class io.github.archipelagomw.events.BouncedEvent
- getObject(String) - Method in class io.github.archipelagomw.events.RetrievedEvent
- getOriginalCommand() - Method in class io.github.archipelagomw.events.InvalidPacketEvent
- GetPacket - Class in io.github.archipelagomw.network.client
-
Used to request a single or multiple values from the server's data storage, see the
ArchipelagoClient.dataStorageSet()for how to write values to the data storage. - GetPacket(Collection<String>) - Constructor for class io.github.archipelagomw.network.client.GetPacket
- getPassword() - Method in class io.github.archipelagomw.Client
- getPlainText() - Method in class io.github.archipelagomw.Print.APPrint
- getPlayer(int, int) - Method in class io.github.archipelagomw.network.server.RoomInfoPacket
- getPlayerID() - Method in class io.github.archipelagomw.events.ReceiveItemEvent
- getPlayerName() - Method in class io.github.archipelagomw.events.ReceiveItemEvent
- getReceivedItemIDs() - Method in class io.github.archipelagomw.ItemManager
- getReceivedItems() - Method in class io.github.archipelagomw.ItemManager
- getRequestID() - Method in class io.github.archipelagomw.events.RetrievedEvent
- getRequestID() - Method in class io.github.archipelagomw.events.SetReplyEvent
- getRequestID() - Method in class io.github.archipelagomw.network.client.GetPacket
- getRequestID() - Method in class io.github.archipelagomw.network.client.SetPacket
- getResult() - Method in class io.github.archipelagomw.events.ConnectionResultEvent
- getRoomInfo() - Method in class io.github.archipelagomw.Client
-
fetches the
- getSeedName() - Method in class io.github.archipelagomw.events.ConnectionAttemptEvent
- getSeedName() - Method in class io.github.archipelagomw.events.ConnectionResultEvent
- getSlot() - Method in class io.github.archipelagomw.Client
- getSlot() - Method in class io.github.archipelagomw.events.ConnectionAttemptEvent
- getSlot() - Method in class io.github.archipelagomw.events.ConnectionResultEvent
- getSlotData(Class<T>) - Method in class io.github.archipelagomw.events.ConnectionAttemptEvent
- getSlotData(Class<T>) - Method in class io.github.archipelagomw.events.ConnectionResultEvent
- getSlotInfo() - Method in class io.github.archipelagomw.Client
- getString(String) - Method in class io.github.archipelagomw.events.BouncedEvent
- getString(String) - Method in class io.github.archipelagomw.events.RetrievedEvent
- getTags() - Method in class io.github.archipelagomw.Client
- getTeam() - Method in class io.github.archipelagomw.Client
- getTeam() - Method in class io.github.archipelagomw.events.ConnectionAttemptEvent
- getTeam() - Method in class io.github.archipelagomw.events.ConnectionResultEvent
- getText() - Method in class io.github.archipelagomw.events.InvalidPacketEvent
- getText() - Method in class io.github.archipelagomw.network.server.PrintPacket
- getType() - Method in class io.github.archipelagomw.events.InvalidPacketEvent
- getUUID() - Static method in class io.github.archipelagomw.Client
-
Gets the UUID of clients on this machine
- getValue() - Method in class io.github.archipelagomw.APResult
- getValue() - Method in enum class io.github.archipelagomw.ClientStatus
- getValue() - Method in enum class io.github.archipelagomw.network.client.CreateAsHint
- getValue() - Method in enum class io.github.archipelagomw.network.client.HintStatus
- getValue() - Method in enum class io.github.archipelagomw.network.Permission
- getValue() - Method in interface io.github.archipelagomw.utils.IntEnum
- getValueAsObject(Class<T>) - Method in class io.github.archipelagomw.events.SetReplyEvent
- getValueAsObject(Type) - Method in class io.github.archipelagomw.events.SetReplyEvent
- getValueAsObject(String, Class<T>) - Method in class io.github.archipelagomw.events.RetrievedEvent
- getValueAsObject(String, Type) - Method in class io.github.archipelagomw.events.RetrievedEvent
- goal - Enum constant in enum class io.github.archipelagomw.network.Permission
- goal - Enum constant in enum class io.github.archipelagomw.network.RemainingMode
- Goal - Enum constant in enum class io.github.archipelagomw.Print.APPrintJsonType
-
A player reached their goal.
- gold - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
- green - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
- green_bg - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
- GROUP - Static variable in class io.github.archipelagomw.flags.NetworkPlayer
-
If set, indicates the slot is a group.
H
- handle(BouncedPacket) - Method in class io.github.archipelagomw.bounce.BouncedManager
- handle(BouncedPacket) - Method in interface io.github.archipelagomw.bounce.BouncedPacketHandler
- handle(BouncedPacket) - Method in class io.github.archipelagomw.bounce.DeathLinkHandler
- hasOriginalCommand() - Method in class io.github.archipelagomw.events.InvalidPacketEvent
- Hint - Enum constant in enum class io.github.archipelagomw.Print.APPrintJsonType
-
A player hinted.
- HINT_AVOID - Enum constant in enum class io.github.archipelagomw.network.client.HintStatus
- HINT_FOUND - Enum constant in enum class io.github.archipelagomw.network.client.HintStatus
- HINT_NO_PRIORITY - Enum constant in enum class io.github.archipelagomw.network.client.HintStatus
- HINT_PRIORITY - Enum constant in enum class io.github.archipelagomw.network.client.HintStatus
- HINT_UNSPECIFIED - Enum constant in enum class io.github.archipelagomw.network.client.HintStatus
- hintCost - Variable in class io.github.archipelagomw.network.server.RoomInfoPacket
- hintCost - Variable in class io.github.archipelagomw.network.server.RoomUpdatePacket
- hintPoints - Variable in class io.github.archipelagomw.network.server.RoomUpdatePacket
- HintStatus - Enum Class in io.github.archipelagomw.network.client
I
- IncompatibleVersion - Enum constant in enum class io.github.archipelagomw.network.ConnectionResult
- index - Variable in class io.github.archipelagomw.network.server.ReceivedItemsPacket
- IntEnum - Interface in io.github.archipelagomw.utils
- IntEnumAdapterFactory - Class in io.github.archipelagomw.utils
- IntEnumAdapterFactory() - Constructor for class io.github.archipelagomw.utils.IntEnumAdapterFactory
- InvalidGame - Enum constant in enum class io.github.archipelagomw.network.ConnectionResult
- InvalidPacket - Class in io.github.archipelagomw.network.server
- InvalidPacket - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- InvalidPacket() - Constructor for class io.github.archipelagomw.network.server.InvalidPacket
- InvalidPacketEvent - Class in io.github.archipelagomw.events
- InvalidPacketEvent(String, String, String) - Constructor for class io.github.archipelagomw.events.InvalidPacketEvent
- InvalidPassword - Enum constant in enum class io.github.archipelagomw.network.ConnectionResult
- InvalidSlot - Enum constant in enum class io.github.archipelagomw.network.ConnectionResult
- io.github.archipelagomw - package io.github.archipelagomw
- io.github.archipelagomw.bounce - package io.github.archipelagomw.bounce
- io.github.archipelagomw.events - package io.github.archipelagomw.events
- io.github.archipelagomw.flags - package io.github.archipelagomw.flags
- io.github.archipelagomw.network - package io.github.archipelagomw.network
- io.github.archipelagomw.network.client - package io.github.archipelagomw.network.client
- io.github.archipelagomw.network.server - package io.github.archipelagomw.network.server
- io.github.archipelagomw.parts - package io.github.archipelagomw.parts
- io.github.archipelagomw.Print - package io.github.archipelagomw.Print
- io.github.archipelagomw.utils - package io.github.archipelagomw.utils
- isCanceled() - Method in class io.github.archipelagomw.events.ConnectionAttemptEvent
- isConnected() - Method in class io.github.archipelagomw.Client
-
Returns true only if connected to an Archipelago server.
- item - Variable in class io.github.archipelagomw.events.PrintJSONEvent
- item - Variable in class io.github.archipelagomw.Print.APPrint
- ItemCheat - Enum constant in enum class io.github.archipelagomw.Print.APPrintJsonType
-
A player used the `!getitem` command.
- itemID - Enum constant in enum class io.github.archipelagomw.Print.APPrintType
- itemID - Variable in class io.github.archipelagomw.parts.NetworkItem
- ItemManager - Class in io.github.archipelagomw
- ItemManager(Client) - Constructor for class io.github.archipelagomw.ItemManager
- itemName - Enum constant in enum class io.github.archipelagomw.Print.APPrintType
- itemName - Variable in class io.github.archipelagomw.parts.NetworkItem
- itemNameToId - Variable in class io.github.archipelagomw.parts.Game
- items - Variable in class io.github.archipelagomw.network.server.ReceivedItemsPacket
- ItemSend - Enum constant in enum class io.github.archipelagomw.Print.APPrintJsonType
-
A player received an item.
- itemsHandling - Variable in class io.github.archipelagomw.network.client.ConnectPacket
- ItemsHandling - Class in io.github.archipelagomw.flags
-
Item Flag variables to read
Client.getItemsHandlingFlags()and setClient.setItemsHandlingFlags(int)
Current item flags:ItemsHandling.SEND_ITEMSItemsHandling.SEND_OWN_ITEMSItemsHandling.SEND_STARTING_INVENTORY - ItemsHandling() - Constructor for class io.github.archipelagomw.flags.ItemsHandling
J
- Join - Enum constant in enum class io.github.archipelagomw.Print.APPrintJsonType
-
A player connected.
- JsonPrintPacket - Class in io.github.archipelagomw.network.server
- JsonPrintPacket() - Constructor for class io.github.archipelagomw.network.server.JsonPrintPacket
K
- key - Variable in class io.github.archipelagomw.events.SetReplyEvent
- key - Variable in class io.github.archipelagomw.network.client.SetPacket
-
The key to manipulate.
- key - Variable in class io.github.archipelagomw.network.server.SetReplyPacket
- keys - Variable in class io.github.archipelagomw.network.client.GetPacket
-
a list of keys to retrieve data for.
- keys - Variable in class io.github.archipelagomw.network.client.SetNotifyPacket
-
a list of datastorage keys to be notified upon their change.
- keys - Variable in class io.github.archipelagomw.network.server.RetrievedPacket
L
- label - Variable in enum class io.github.archipelagomw.network.RemainingMode.ForfeitMode
- LEFT_SHIFT - Enum constant in enum class io.github.archipelagomw.network.client.SetPacket.Operation
-
Applies a bitwise left-shift to the current value of the key on the server by @value.
- loadDataPackage() - Method in class io.github.archipelagomw.Client
- locationCheckPoints - Variable in class io.github.archipelagomw.network.server.RoomInfoPacket
- locationCheckPoints - Variable in class io.github.archipelagomw.network.server.RoomUpdatePacket
- LocationChecks - Class in io.github.archipelagomw.network.client
- LocationChecks - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- LocationChecks() - Constructor for class io.github.archipelagomw.network.client.LocationChecks
- locationID - Enum constant in enum class io.github.archipelagomw.Print.APPrintType
- locationID - Variable in class io.github.archipelagomw.parts.NetworkItem
- LocationInfo - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- LocationInfoEvent - Class in io.github.archipelagomw.events
- LocationInfoEvent(ArrayList<NetworkItem>) - Constructor for class io.github.archipelagomw.events.LocationInfoEvent
- LocationInfoPacket - Class in io.github.archipelagomw.network.server
- LocationInfoPacket() - Constructor for class io.github.archipelagomw.network.server.LocationInfoPacket
- LocationManager - Class in io.github.archipelagomw
- LocationManager(Client) - Constructor for class io.github.archipelagomw.LocationManager
- locationName - Enum constant in enum class io.github.archipelagomw.Print.APPrintType
- locationName - Variable in class io.github.archipelagomw.parts.NetworkItem
- locationNameToId - Variable in class io.github.archipelagomw.parts.Game
- locations - Variable in class io.github.archipelagomw.events.LocationInfoEvent
- locations - Variable in class io.github.archipelagomw.network.client.CreateHintPacket
- locations - Variable in class io.github.archipelagomw.network.client.LocationChecks
- locations - Variable in class io.github.archipelagomw.network.client.LocationScouts
- locations - Variable in class io.github.archipelagomw.network.server.LocationInfoPacket
- LocationScouts - Class in io.github.archipelagomw.network.client
- LocationScouts - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- LocationScouts(ArrayList<Long>) - Constructor for class io.github.archipelagomw.network.client.LocationScouts
- LocationScouts(ArrayList<Long>, CreateAsHint) - Constructor for class io.github.archipelagomw.network.client.LocationScouts
M
- magenta - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
- magenta_bg - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
- MAX - Enum constant in enum class io.github.archipelagomw.network.client.SetPacket.Operation
-
Sets the current value of the key on the server to @value if @value is bigger.
- message - Variable in class io.github.archipelagomw.Print.APPrint
- MIN - Enum constant in enum class io.github.archipelagomw.network.client.SetPacket.Operation
-
Sets the current value of the key on the server to @value if @value is lower.
- missingLocations - Variable in class io.github.archipelagomw.network.server.ConnectedPacket
- missingLocations - Variable in class io.github.archipelagomw.network.server.RoomUpdatePacket
- MODULO - Enum constant in enum class io.github.archipelagomw.network.client.SetPacket.Operation
-
Sets the current value of the key on the server to the remainder after division by @value.
- MULTIPLY - Enum constant in enum class io.github.archipelagomw.network.client.SetPacket.Operation
-
Multiplies the current value of the key on the server by @value.
N
- name - Variable in class io.github.archipelagomw.network.client.ConnectPacket
- name - Variable in class io.github.archipelagomw.parts.NetworkPlayer
- name - Variable in class io.github.archipelagomw.parts.NetworkSlot
- NetworkItem - Class in io.github.archipelagomw.flags
-
Flags that will tell you more about the item that was sent.
NetworkItem.ADVANCEMENT,NetworkItem.USEFUL,NetworkItem.TRAP - NetworkItem - Class in io.github.archipelagomw.parts
- NetworkItem() - Constructor for class io.github.archipelagomw.flags.NetworkItem
- NetworkItem() - Constructor for class io.github.archipelagomw.parts.NetworkItem
- NetworkPlayer - Class in io.github.archipelagomw.flags
-
Flags that will tell you more about the slot type.
NetworkPlayer.SPECTATOR,NetworkPlayer.PLAYER,NetworkPlayer.GROUP - NetworkPlayer - Class in io.github.archipelagomw.parts
- NetworkPlayer() - Constructor for class io.github.archipelagomw.flags.NetworkPlayer
- NetworkPlayer(int, int, String) - Constructor for class io.github.archipelagomw.parts.NetworkPlayer
- networkPlayers - Variable in class io.github.archipelagomw.network.server.RoomInfoPacket
- networkPlayers - Variable in class io.github.archipelagomw.network.server.RoomUpdatePacket
- NetworkSlot - Class in io.github.archipelagomw.parts
- NetworkSlot(String, String, int) - Constructor for class io.github.archipelagomw.parts.NetworkSlot
- NO - Enum constant in enum class io.github.archipelagomw.network.client.CreateAsHint
- none - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
O
- onClose(String, int) - Method in class io.github.archipelagomw.Client
- onError(Exception) - Method in class io.github.archipelagomw.Client
- operations - Variable in class io.github.archipelagomw.network.client.SetPacket
-
Operations to apply to the value on the server, multiple operations can be present, and they will be executed in order of appearance.
- OR - Enum constant in enum class io.github.archipelagomw.network.client.SetPacket.Operation
-
Applies a bitwise OR to the current value of the key on the server with @value.
- Original_cmd - Variable in class io.github.archipelagomw.network.server.InvalidPacket
- original_value - Variable in class io.github.archipelagomw.events.SetReplyEvent
- original_Value - Variable in class io.github.archipelagomw.network.server.SetReplyPacket
- OTHER_ERROR - Enum constant in enum class io.github.archipelagomw.APResult.ResultCode
P
- Part - Enum constant in enum class io.github.archipelagomw.Print.APPrintJsonType
-
A player disconnected.
- parts - Variable in class io.github.archipelagomw.Print.APPrint
- password - Variable in class io.github.archipelagomw.network.client.ConnectPacket
- password - Variable in class io.github.archipelagomw.network.server.RoomInfoPacket
- password - Variable in class io.github.archipelagomw.network.server.RoomUpdatePacket
- Permission - Enum Class in io.github.archipelagomw.network
- permissions - Variable in class io.github.archipelagomw.network.server.RoomInfoPacket
- player - Variable in class io.github.archipelagomw.events.PrintJSONEvent
- player - Variable in class io.github.archipelagomw.network.client.CreateHintPacket
- player - Variable in class io.github.archipelagomw.Print.APPrintPart
- PLAYER - Static variable in class io.github.archipelagomw.flags.NetworkPlayer
-
If set, indicates the slot is a player
- playerID - Enum constant in enum class io.github.archipelagomw.Print.APPrintType
- playerID - Variable in class io.github.archipelagomw.parts.NetworkItem
- playerName - Enum constant in enum class io.github.archipelagomw.Print.APPrintType
- playerName - Variable in class io.github.archipelagomw.parts.NetworkItem
- players - Variable in class io.github.archipelagomw.network.server.ConnectedPacket
- POP - Enum constant in enum class io.github.archipelagomw.network.client.SetPacket.Operation
-
List or Dict: for lists it will remove the index of the @value given.
- POWER - Enum constant in enum class io.github.archipelagomw.network.client.SetPacket.Operation
-
Multiplies the current value of the key on the server to the power of @value.
- Print - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- PrintJSON - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- PrintJSONEvent - Class in io.github.archipelagomw.events
-
event that is fired when the server wishes to send a message to the user.
- PrintJSONEvent(APPrint, APPrintJsonType, int, NetworkItem) - Constructor for class io.github.archipelagomw.events.PrintJSONEvent
- PrintPacket - Class in io.github.archipelagomw.network.server
- PrintPacket() - Constructor for class io.github.archipelagomw.network.server.PrintPacket
- protocolVersion - Static variable in class io.github.archipelagomw.Client
- purple_bg - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
R
- ReceivedItems - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- ReceivedItemsPacket - Class in io.github.archipelagomw.network.server
- ReceivedItemsPacket() - Constructor for class io.github.archipelagomw.network.server.ReceivedItemsPacket
- ReceiveItemEvent - Class in io.github.archipelagomw.events
- ReceiveItemEvent(NetworkItem, int) - Constructor for class io.github.archipelagomw.events.ReceiveItemEvent
- receiveItems(List<NetworkItem>, int) - Method in class io.github.archipelagomw.ItemManager
- receiving - Variable in class io.github.archipelagomw.Print.APPrint
- reconnect() - Method in class io.github.archipelagomw.Client
-
this should not need to be called externally but is left public just in case.
- red - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
- red_bg - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
- registerListener(Object) - Method in class io.github.archipelagomw.EventManager
-
Use to register for Events that come from the Archipelago server.
- Release - Enum constant in enum class io.github.archipelagomw.Print.APPrintJsonType
-
A player released the remaining items in their world.
- remainingMode - Variable in class io.github.archipelagomw.network.server.RoomUpdatePacket
- RemainingMode - Enum Class in io.github.archipelagomw.network
- RemainingMode.ForfeitMode - Enum Class in io.github.archipelagomw.network
- REMOVE - Enum constant in enum class io.github.archipelagomw.network.client.SetPacket.Operation
-
List only: removes the first instance of @value found in the list.
- removeHandler(BouncedPacketHandler) - Method in class io.github.archipelagomw.bounce.BouncedManager
-
Removes a handler from intercepting packets with.
- removeTag(String) - Method in class io.github.archipelagomw.Client
-
removes supplied tag, if it exists.
- REPLACE - Enum constant in enum class io.github.archipelagomw.network.client.SetPacket.Operation
-
Sets the current value of the key on the server to the value given in
addDataStorageOperation(Operation, Value). - requestID - Variable in class io.github.archipelagomw.network.server.RetrievedPacket
- requestID - Variable in class io.github.archipelagomw.network.server.SetReplyPacket
- resendAllCheckedLocations() - Method in class io.github.archipelagomw.LocationManager
- Retrieved - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- RetrievedEvent - Class in io.github.archipelagomw.events
- RetrievedEvent(HashMap<String, Object>, JsonObject, int) - Constructor for class io.github.archipelagomw.events.RetrievedEvent
- RetrievedPacket - Class in io.github.archipelagomw.network.server
- RetrievedPacket() - Constructor for class io.github.archipelagomw.network.server.RetrievedPacket
- RIGHT_SHIFT - Enum constant in enum class io.github.archipelagomw.network.client.SetPacket.Operation
-
Applies a bitwise right-shift to the current value of the key on the server by @value.
- RoomInfo - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- RoomInfoPacket - Class in io.github.archipelagomw.network.server
- RoomInfoPacket() - Constructor for class io.github.archipelagomw.network.server.RoomInfoPacket
- RoomUpdate - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- RoomUpdatePacket - Class in io.github.archipelagomw.network.server
- RoomUpdatePacket() - Constructor for class io.github.archipelagomw.network.server.RoomUpdatePacket
S
- saveDataPackage() - Method in class io.github.archipelagomw.Client
- Say - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- SayPacket - Class in io.github.archipelagomw.network.client
- SayPacket(String) - Constructor for class io.github.archipelagomw.network.client.SayPacket
- scoutLocations(ArrayList<Long>) - Method in class io.github.archipelagomw.Client
-
Ask the server for information about what is in locations.
- scoutLocations(ArrayList<Long>, CreateAsHint) - Method in class io.github.archipelagomw.Client
-
Ask the server for information about what is in locations.
- seedName - Variable in class io.github.archipelagomw.network.server.RoomInfoPacket
- SEND_ITEMS - Static variable in class io.github.archipelagomw.flags.ItemsHandling
-
Tells the server to send you items from other worlds.
- SEND_OWN_ITEMS - Static variable in class io.github.archipelagomw.flags.ItemsHandling
-
Tells the server to send your own items to you (remote items game)
- SEND_STARTING_INVENTORY - Static variable in class io.github.archipelagomw.flags.ItemsHandling
-
Tells the server to send you any items that You should start with.
- sendBounce(BouncePacket) - Method in class io.github.archipelagomw.Client
-
sends a bouncepacket to the server, such as for deathlink
- sendChat(String) - Method in class io.github.archipelagomw.Client
-
Sends a Chat message to all other connected Clients.
- sendDeathlink(String, String) - Method in class io.github.archipelagomw.Client
-
Helper for sending a death link bounce packet.
- sendDeathLink(String, String) - Method in class io.github.archipelagomw.bounce.DeathLinkHandler
- sendIfChecked(Set<Long>) - Method in class io.github.archipelagomw.LocationManager
- sendPackets(List<APPacket>) - Method in class io.github.archipelagomw.Client
-
Enables sending multiple packets at once.
- ServerChat - Enum constant in enum class io.github.archipelagomw.Print.APPrintJsonType
-
The server broadcast a message.
- set(double) - Method in class io.github.archipelagomw.utils.AtomicDouble
- Set - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- setCanceled(boolean) - Method in class io.github.archipelagomw.events.ConnectionAttemptEvent
- setData(HashMap<String, Object>) - Method in class io.github.archipelagomw.network.client.BouncePacket
- setDeathLinkEnabled(boolean) - Method in class io.github.archipelagomw.Client
-
Enable or disable receiving death links.
- setGame(String) - Method in class io.github.archipelagomw.Client
-
Sets the name of the game to send to Archipelago's servers
- setGameState(ClientStatus) - Method in class io.github.archipelagomw.Client
-
Update the current game status.
- setItemsHandlingFlags(int) - Method in class io.github.archipelagomw.Client
-
fetch the itemflags that have been set, bitwise Or against
ItemsHandlingto read. - setMissingLocations(Set<Long>) - Method in class io.github.archipelagomw.LocationManager
- setName(String) - Method in class io.github.archipelagomw.Client
-
sets the slot name to connect to an Archcipelago server with.
- SetNotify - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- SetNotifyPacket - Class in io.github.archipelagomw.network.client
- SetNotifyPacket(Collection<String>) - Constructor for class io.github.archipelagomw.network.client.SetNotifyPacket
- SetPacket - Class in io.github.archipelagomw.network.client
- SetPacket(String, Object) - Constructor for class io.github.archipelagomw.network.client.SetPacket
- SetPacket.Operation - Enum Class in io.github.archipelagomw.network.client
-
A List of operations that can be performed on the value stored on the server.
SetPacket.Operation.REPLACE,SetPacket.Operation.DEFAULT,SetPacket.Operation.ADD,SetPacket.Operation.MULTIPLY,SetPacket.Operation.POWER,SetPacket.Operation.MODULO,SetPacket.Operation.MAX,SetPacket.Operation.MIN,SetPacket.Operation.AND,SetPacket.Operation.OR,SetPacket.Operation.XOR,SetPacket.Operation.LEFT_SHIFT,SetPacket.Operation.RIGHT_SHIFT,SetPacket.Operation.REMOVE,SetPacket.Operation.POP,SetPacket.Operation.UPDATE - setPassword(String) - Method in class io.github.archipelagomw.Client
-
sets a password to authenticate with to join a password protected room.
- SetReply - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- SetReplyEvent - Class in io.github.archipelagomw.events
- SetReplyEvent(String, Object, Object, JsonElement, int) - Constructor for class io.github.archipelagomw.events.SetReplyEvent
- SetReplyPacket - Class in io.github.archipelagomw.network.server
- SetReplyPacket() - Constructor for class io.github.archipelagomw.network.server.SetReplyPacket
- setTags(Set<String>) - Method in class io.github.archipelagomw.Client
-
overwrite, and set all tags sent to the Archipelago server.
- slot - Variable in class io.github.archipelagomw.network.server.ConnectedPacket
- slot - Variable in class io.github.archipelagomw.network.server.SetReplyPacket
- slot - Variable in class io.github.archipelagomw.parts.NetworkPlayer
- slot - Variable in class io.github.archipelagomw.Print.APPrint
- SlotAlreadyTaken - Enum constant in enum class io.github.archipelagomw.network.ConnectionResult
- slotInfo - Variable in class io.github.archipelagomw.network.server.ConnectedPacket
- slots - Variable in class io.github.archipelagomw.events.BouncedEvent
- slots - Variable in class io.github.archipelagomw.network.client.BouncePacket
- slots - Variable in class io.github.archipelagomw.network.server.BouncedPacket
- source - Variable in class io.github.archipelagomw.events.DeathLinkEvent
- SPECTATOR - Static variable in class io.github.archipelagomw.flags.NetworkPlayer
-
If set, indicates the slot is a spectator
- status - Variable in class io.github.archipelagomw.network.client.CreateHintPacket
- StatusUpdate - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- StatusUpdatePacket - Class in io.github.archipelagomw.network.client
- StatusUpdatePacket(ClientStatus) - Constructor for class io.github.archipelagomw.network.client.StatusUpdatePacket
- success() - Static method in class io.github.archipelagomw.APResult
- success(T) - Static method in class io.github.archipelagomw.APResult
- Success - Enum constant in enum class io.github.archipelagomw.network.ConnectionResult
- SUCCESS - Enum constant in enum class io.github.archipelagomw.APResult.ResultCode
- sync() - Method in class io.github.archipelagomw.Client
-
manually trigger a resync to the Archipelago server.
- Sync - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- SyncPacket - Class in io.github.archipelagomw.network.client
- SyncPacket() - Constructor for class io.github.archipelagomw.network.client.SyncPacket
T
- tags - Variable in class io.github.archipelagomw.events.BouncedEvent
- tags - Variable in class io.github.archipelagomw.network.client.BouncePacket
- tags - Variable in class io.github.archipelagomw.network.client.ConnectPacket
- tags - Variable in class io.github.archipelagomw.network.server.BouncedPacket
- tags - Variable in class io.github.archipelagomw.network.server.ConnectUpdatePacket
- tags - Variable in class io.github.archipelagomw.network.server.RoomInfoPacket
- tags - Variable in class io.github.archipelagomw.network.server.RoomUpdatePacket
- tags - Variable in class io.github.archipelagomw.Print.APPrint
- TagsChanged - Enum constant in enum class io.github.archipelagomw.Print.APPrintJsonType
-
A player changed their tags.
- team - Variable in class io.github.archipelagomw.network.server.ConnectedPacket
- team - Variable in class io.github.archipelagomw.parts.NetworkPlayer
- team - Variable in class io.github.archipelagomw.Print.APPrint
- text - Enum constant in enum class io.github.archipelagomw.Print.APPrintType
- text - Variable in class io.github.archipelagomw.network.server.InvalidPacket
- text - Variable in class io.github.archipelagomw.Print.APPrintPart
- time - Variable in class io.github.archipelagomw.events.DeathLinkEvent
- time - Variable in class io.github.archipelagomw.network.server.RoomInfoPacket
- TRAP - Static variable in class io.github.archipelagomw.flags.NetworkItem
-
If set, indicates the item is a trap
- Tutorial - Enum constant in enum class io.github.archipelagomw.Print.APPrintJsonType
-
The client has triggered a tutorial message, such as when first connecting.
- type - Variable in class io.github.archipelagomw.events.PrintJSONEvent
- type - Variable in class io.github.archipelagomw.network.server.InvalidPacket
- type - Variable in class io.github.archipelagomw.parts.NetworkSlot
- type - Variable in class io.github.archipelagomw.Print.APPrint
- type - Variable in class io.github.archipelagomw.Print.APPrintPart
U
- unauthenticated() - Static method in class io.github.archipelagomw.APResult
- UNAUTHENTICATED - Enum constant in enum class io.github.archipelagomw.APResult.ResultCode
- underline - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
- Unknown - Enum constant in enum class io.github.archipelagomw.Print.APPrintJsonType
-
The Message type was not set, or is invalid.
- unRegisterListener(Object) - Method in class io.github.archipelagomw.EventManager
-
Use to unregister for Events that come from the Archipelago server.
- update(DataPackage) - Method in class io.github.archipelagomw.parts.DataPackage
- update(String, Game) - Method in class io.github.archipelagomw.parts.DataPackage
- UPDATE - Enum constant in enum class io.github.archipelagomw.network.client.SetPacket.Operation
-
Dict only: Updates the dictionary with the specified elements given in @value creating new keys, or updating old ones if they previously existed.
- UpdateHint - Enum constant in enum class io.github.archipelagomw.network.APPacketType
- UpdateHintPacket - Class in io.github.archipelagomw.network.client
- UpdateHintPacket() - Constructor for class io.github.archipelagomw.network.client.UpdateHintPacket
- USEFUL - Static variable in class io.github.archipelagomw.flags.NetworkItem
-
If set, indicates the item is important but not in a way that unlocks advancement
- Utils - Class in io.github.archipelagomw
- Utils() - Constructor for class io.github.archipelagomw.Utils
- uuid - Variable in class io.github.archipelagomw.network.client.ConnectPacket
V
- value - Variable in class io.github.archipelagomw.events.SetReplyEvent
- value - Variable in enum class io.github.archipelagomw.network.client.CreateAsHint
- value - Variable in enum class io.github.archipelagomw.network.Permission
- value - Variable in class io.github.archipelagomw.network.server.SetReplyPacket
- valueOf(String) - Static method in enum class io.github.archipelagomw.APResult.ResultCode
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class io.github.archipelagomw.ClientStatus
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class io.github.archipelagomw.network.APPacketType
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class io.github.archipelagomw.network.client.CreateAsHint
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class io.github.archipelagomw.network.client.HintStatus
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class io.github.archipelagomw.network.client.SetPacket.Operation
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class io.github.archipelagomw.network.ConnectionResult
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class io.github.archipelagomw.network.Permission
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class io.github.archipelagomw.network.RemainingMode.ForfeitMode
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class io.github.archipelagomw.network.RemainingMode
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class io.github.archipelagomw.Print.APPrintColor
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class io.github.archipelagomw.Print.APPrintJsonType
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class io.github.archipelagomw.Print.APPrintType
-
Returns the enum constant of this class with the specified name.
- values() - Static method in enum class io.github.archipelagomw.APResult.ResultCode
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class io.github.archipelagomw.ClientStatus
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class io.github.archipelagomw.network.APPacketType
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class io.github.archipelagomw.network.client.CreateAsHint
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class io.github.archipelagomw.network.client.HintStatus
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class io.github.archipelagomw.network.client.SetPacket.Operation
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class io.github.archipelagomw.network.ConnectionResult
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class io.github.archipelagomw.network.Permission
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class io.github.archipelagomw.network.RemainingMode.ForfeitMode
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class io.github.archipelagomw.network.RemainingMode
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class io.github.archipelagomw.Print.APPrintColor
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class io.github.archipelagomw.Print.APPrintJsonType
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class io.github.archipelagomw.Print.APPrintType
-
Returns an array containing the constants of this enum class, in the order they are declared.
- version - Variable in class io.github.archipelagomw.network.client.ConnectPacket
- version - Variable in class io.github.archipelagomw.network.server.RoomInfoPacket
- version - Variable in class io.github.archipelagomw.network.server.RoomUpdatePacket
- Version - Class in io.github.archipelagomw.parts
- Version(int, int, int) - Constructor for class io.github.archipelagomw.parts.Version
- versions - Variable in class io.github.archipelagomw.Client
W
- want_reply - Variable in class io.github.archipelagomw.network.client.SetPacket
-
If true, the server will send a
SetReplyEventresponse back to the client. - white - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
- white_bg - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
- writeFromSave(List<NetworkItem>, int) - Method in class io.github.archipelagomw.ItemManager
X
- XOR - Enum constant in enum class io.github.archipelagomw.network.client.SetPacket.Operation
-
Applies a bitwise Exclusive OR to the current value of the key on the server with @value.
Y
- yellow - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
- yellow_bg - Enum constant in enum class io.github.archipelagomw.Print.APPrintColor
All Classes and Interfaces|All Packages|Constant Field Values|Serialized Form