Interface BouncedPacketHandler

All Known Implementing Classes:
DeathLinkHandler

public interface BouncedPacketHandler
Used to facilitate protocols over bounce packets. Clients should use this when they want to implement protocol specific bounce packets, such as deathlink, ringlink, and traplink.