Enum Class HintStatus

java.lang.Object
java.lang.Enum<HintStatus>
io.github.archipelagomw.network.client.HintStatus
All Implemented Interfaces:
IntEnum, Serializable, Comparable<HintStatus>, Constable

public enum HintStatus extends Enum<HintStatus> implements IntEnum
  • Enum Constant Details

    • HINT_UNSPECIFIED

      public static final HintStatus HINT_UNSPECIFIED
    • HINT_NO_PRIORITY

      public static final HintStatus HINT_NO_PRIORITY
    • HINT_AVOID

      public static final HintStatus HINT_AVOID
    • HINT_PRIORITY

      public static final HintStatus HINT_PRIORITY
    • HINT_FOUND

      public static final HintStatus HINT_FOUND
  • Method Details

    • values

      public static HintStatus[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static HintStatus valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getValue

      public int getValue()
      Specified by:
      getValue in interface IntEnum