All Classes and Interfaces
Class
Description
tag a method with this who's only parameter is a class that extends
EventA handler for managing protocol specific bounce packets.
Used to facilitate protocols over bounce packets.
A Status to send to the server.
event that is fired whenever you receive a death link from another player.
Manages registering and calling events
Used to request a single or multiple values from the server's data storage, see the
ArchipelagoClient.dataStorageSet() for how to write values to the data storage.Item Flag variables to read
Current item flags:
Client.getItemsHandlingFlags() and set Client.setItemsHandlingFlags(int)
Current item flags:
ItemsHandling.SEND_ITEMS ItemsHandling.SEND_OWN_ITEMS ItemsHandling.SEND_STARTING_INVENTORYFlags that will tell you more about the item that was sent.
NetworkItem.ADVANCEMENT,
NetworkItem.USEFUL,
NetworkItem.TRAPFlags that will tell you more about the slot type.
NetworkPlayer.SPECTATOR,
NetworkPlayer.PLAYER,
NetworkPlayer.GROUPevent that is fired when the server wishes to send a message to the user.
A List of operations that can be performed on the value stored on the server.
SetPacket.Operation.REPLACE,
SetPacket.Operation.DEFAULT,
SetPacket.Operation.ADD,
SetPacket.Operation.MULTIPLY,
SetPacket.Operation.POWER,
SetPacket.Operation.MODULO,
SetPacket.Operation.MAX,
SetPacket.Operation.MIN,
SetPacket.Operation.AND,
SetPacket.Operation.OR,
SetPacket.Operation.XOR,
SetPacket.Operation.LEFT_SHIFT,
SetPacket.Operation.RIGHT_SHIFT,
SetPacket.Operation.REMOVE,
SetPacket.Operation.POP,
SetPacket.Operation.UPDATE