Package io.github.archipelagomw.bounce
Interface BouncedPacketHandler
- All Known Implementing Classes:
DeathLinkHandler
public interface BouncedPacketHandler
Used to facilitate protocols over bounce packets. Clients should use this when they want to implement
protocol specific bounce packets, such as deathlink, ringlink, and traplink.
-
Method Summary
Modifier and TypeMethodDescriptionbooleancanHandle(BouncedPacket packet) Whether this BouncedPacketHandler can handle the provided packet.voidhandle(BouncedPacket packet)
-
Method Details
-
canHandle
Whether this BouncedPacketHandler can handle the provided packet. If it can, no other packet handler will be called, and theBouncedEventwill not be emitted.- Parameters:
packet- The packet to check- Returns:
- true if this handler should process the packet
-
handle
- Parameters:
packet- The BouncedPacket.
-